@@ -137,7 +137,14 @@ def hlsparse(config, res, url, **kwargs):
     elif m3u8.media_segment:
         config.set("segments", False)
         streams[0] = HLS(
-            copy.copy(config), url, 0, cookies=res.cookies, keycookie=keycookie, authorization=authorization, output=output, segments=False
+            copy.copy(config),
+            url,
+            0,
+            cookies=res.cookies,
+            keycookie=keycookie,
+            authorization=authorization,
+            output=output,
+            segments=False,
         )
 
     else:
@@ -154,9 +161,10 @@ class HLS(VideoRetriever):
     def download(self):
         self.output_extention = "ts"
         if self.segments:
-            if self.audio:
+            if self.audio and not self.config.get("only_video"):
                 self._download(self.audio, file_name=(copy.copy(self.output), "audio.ts"))
-            self._download(self.url, file_name=(self.output, "ts"))
+            if not self.config.get("only_audio"):
+                self._download(self.url, file_name=(self.output, "ts"))
 
         else:
             # Ignore audio
@@ -221,10 +229,14 @@ class HLS(VideoRetriever):
                     cipher = Cipher(algorithms.AES(key), modes.CBC(iv), backend=backend)
                     decryptor = cipher.decryptor()
 
-                if decryptor:
-                    data = decryptor.update(data)
-                else:
-                    raise ValueError("No decryptor found for encrypted hls steam.")
+                # In some cases the playlist say its encrypted but the files is not.
+                # This happen on svtplay 5.1ch stream where it started with ID3..
+                # Adding the other ones is header for mpeg-ts files. third byte is 10 or 11..
+                if data[:3] != b"ID3" and data[:3] != b"\x47\x40\x11" and data[:3] != b"\x47\x40\x10":
+                    if decryptor:
+                        data = decryptor.update(data)
+                    else:
+                        raise ValueError("No decryptor found for encrypted hls steam.")
 
             file_d.write(data)
 
@@ -296,7 +308,12 @@ class M3U8:
 
     def __str__(self):
         return "Version: {}\nMedia Segment: {}\nMedia Playlist: {}\nMaster Playlist: {}\nEncrypted: {}\tIndependent_segments: {}".format(
-            self.version, self.media_segment, self.media_playlist, self.master_playlist, self.encrypted, self.independent_segments
+            self.version,
+            self.media_segment,
+            self.media_playlist,
+            self.master_playlist,
+            self.encrypted,
+            self.independent_segments,
         )
 
     def parse_m3u(self, data):
