@@ -61,7 +61,10 @@ class Bigbrother(Service, OpenGraphThumbMixin):
         for i in renditions:
             if i["defaultURL"].endswith("f4m"):
                 streams = hdsparse(
-                    copy.copy(self.config), self.http.request("get", i["defaultURL"], params={"hdcore": "3.7.0"}), i["defaultURL"], output=self.output
+                    copy.copy(self.config),
+                    self.http.request("get", i["defaultURL"], params={"hdcore": "3.7.0"}),
+                    i["defaultURL"],
+                    output=self.output,
                 )
                 for n in list(streams.keys()):
                     yield streams[n]
