@@ -52,7 +52,10 @@ class Nrk(Service, OpenGraphThumbMixin):
                 yield streams[n]
 
         streams = hdsparse(
-            copy.copy(self.config), self.http.request("get", manifest_url, params={"hdcore": "3.7.0"}), manifest_url, output=self.output
+            copy.copy(self.config),
+            self.http.request("get", manifest_url, params={"hdcore": "3.7.0"}),
+            manifest_url,
+            output=self.output,
         )
         if streams:
             for n in list(streams.keys()):
